summaryrefslogtreecommitdiffstats
path: root/lib/koproperty/property.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/koproperty/property.h')
-rw-r--r--lib/koproperty/property.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/koproperty/property.h b/lib/koproperty/property.h
index 8d7f01d6..bc8a503e 100644
--- a/lib/koproperty/property.h
+++ b/lib/koproperty/property.h
@@ -222,20 +222,20 @@ class KOPROPERTY_EXPORT Property
(with newline, if any) for displaying within a property editor. */
Property(const TQCString &name, const TQVariant &value = TQVariant(),
const TQString &caption = TQString(), const TQString &description = TQString(),
- int type = Auto, Property* tqparent = 0);
+ int type = Auto, Property* parent = 0);
/*! Constructs property of \ref ValueFromList type. */
Property(const TQCString &name, const TQStringList &keys, const TQStringList &strings,
const TQVariant &value = TQVariant(),
const TQString &caption = TQString(), const TQString &description = TQString(),
- int type = ValueFromList, Property* tqparent = 0);
+ int type = ValueFromList, Property* parent = 0);
/*! Constructs property of \ref ValueFromList type.
This is overload of the above ctor added for convenience. */
Property(const TQCString &name, ListData* listData,
const TQVariant &value = TQVariant(),
const TQString &caption = TQString(), const TQString &description = TQString(),
- int type = ValueFromList, Property* tqparent = 0);
+ int type = ValueFromList, Property* parent = 0);
/*! Constructs a deep copy of \a prop property. */
Property(const Property &prop);
@@ -313,8 +313,8 @@ class KOPROPERTY_EXPORT Property
/*! \return a child property for \a name, or NULL if there is no property with that name. */
Property* child(const TQCString &name);
- /*! \return tqparent property for this property, or NULL if there is no tqparent property. */
- Property* tqparent() const;
+ /*! \return parent property for this property, or NULL if there is no parent property. */
+ Property* parent() const;
/*! \return the custom property for this property.or NULL if there was
no custom property defined. */